@@ -37,8 +37,10 @@
 
 #include "dealer.h"
 #include "dealerinfo.h"
+#include "kpat_debug.h"
 #include "messagebox.h"
 #include "renderer.h"
+#include "shuffle.h"
 #include "speeds.h"
 #include "patsolve/solverinterface.h"
 #include "version.h"
@@ -47,7 +49,6 @@
 #include "KCardTheme"
 
 #include <KConfigGroup>
-#include <QDebug>
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KRandom>
@@ -66,26 +67,6 @@ namespace
 {
     const qreal wonBoxToSceneSizeRatio = 0.7;
 
-    QList<KCard*> shuffled( const QList<KCard*> & cards, int seed )
-    {
-        Q_ASSERT( seed > 0 );
-
-        QList<KCard*> result = cards;
-        for ( int i = result.size(); i > 1; --i )
-        {
-            // We use the same pseudorandom number generation algorithm as Windows
-            // Freecell, so that game numbers are the same between the two applications.
-            // For more inforation, see
-            // http://support.microsoft.com/default.aspx?scid=kb;EN-US;Q28150
-            seed = 214013 * seed + 2531011;
-            int rand = ( seed >> 16 ) & 0x7fff;
-
-            result.swap( i - 1, rand % i );
-        }
-
-        return result;
-    }
-
     QString solverStatusMessage( int status, bool everWinnable )
     {
         switch ( status )
@@ -291,7 +272,7 @@ bool DealerScene::loadLegacyFile( QIODevice * io )
     {
         if ( xml.name() != "pile" )
         {
-            qWarning() << "Expected a \"pile\" tag. Found a" << xml.name() << "tag.";
+            qCWarning(KPAT_LOG) << "Expected a \"pile\" tag. Found a" << xml.name() << "tag.";
             return false;
         }
 
@@ -300,7 +281,7 @@ bool DealerScene::loadLegacyFile( QIODevice * io )
         QHash<int,PatPile*>::const_iterator it = piles.constFind( index );
         if ( !ok || it == piles.constEnd() )
         {
-            qWarning() << "Unrecognized pile index:" << xml.attributes().value( QStringLiteral("index") );
+            qCWarning(KPAT_LOG) << "Unrecognized pile index:" << xml.attributes().value( QStringLiteral("index") );
             return false;
         }
 
@@ -312,7 +293,7 @@ bool DealerScene::loadLegacyFile( QIODevice * io )
         {
             if ( xml.name() != "card" )
             {
-                qWarning() << "Expected a \"card\" tag. Found a" << xml.name() << "tag.";
+                qCWarning(KPAT_LOG) << "Expected a \"card\" tag. Found a" << xml.name() << "tag.";
                 return false;
             }
             
@@ -326,7 +307,7 @@ bool DealerScene::loadLegacyFile( QIODevice * io )
 
             if ( !suitOk || !rankOk || !faceUpOk || !card )
             {
-                qWarning() << "Unrecognized card: suit=" << xml.attributes().value(QStringLiteral("suit"))
+                qCWarning(KPAT_LOG) << "Unrecognized card: suit=" << xml.attributes().value(QStringLiteral("suit"))
                            << " value=" << xml.attributes().value(QStringLiteral("value"))
                            << " faceup=" << xml.attributes().value(QStringLiteral("faceup"));
                 return false;
@@ -364,6 +345,11 @@ void DealerScene::saveFile( QIODevice * io )
         xml.writeAttribute( QStringLiteral("game-type-options"), getGameOptions() );
     xml.writeAttribute( QStringLiteral("deal-number"), QString::number( gameNumber() ) );
 
+    if (!m_currentState) {
+        deck()->stopAnimations();
+        takeState();
+    }
+
     QList<GameState*> allStates;
     for ( int i = 0; i < m_undoStack.size(); ++i )
         allStates << m_undoStack.at( i );
@@ -430,7 +416,7 @@ bool DealerScene::loadFile( QIODevice * io )
 
     if ( xml.name() != "kpat-game" )
     {
-        qWarning() << "First tag is not \"kpat-game\"";
+        qCWarning(KPAT_LOG) << "First tag is not \"kpat-game\"";
         return false;
     }
 
@@ -451,7 +437,7 @@ bool DealerScene::loadFile( QIODevice * io )
     {
         if ( xml.name() != "state" )
         {
-            qWarning() << "Expected a \"state\" tag. Found a" << xml.name() << "tag.";
+            qCWarning(KPAT_LOG) << "Expected a \"state\" tag. Found a" << xml.name() << "tag.";
             return false;
         }
 
@@ -467,7 +453,7 @@ bool DealerScene::loadFile( QIODevice * io )
         {
             if ( xml.name() != "move" )
             {
-                qWarning() << "Expected a \"move\" tag. Found a" << xml.name() << "tag.";
+                qCWarning(KPAT_LOG) << "Expected a \"move\" tag. Found a" << xml.name() << "tag.";
                 return false;
             }
 
@@ -479,7 +465,7 @@ bool DealerScene::loadFile( QIODevice * io )
 
             if ( !pile || !indexOk )
             {
-                qWarning() << "Unrecognized pile or index.";
+                qCWarning(KPAT_LOG) << "Unrecognized pile or index.";
                 return false;
             }
 
@@ -487,14 +473,14 @@ bool DealerScene::loadFile( QIODevice * io )
             {
                 if ( xml.name() != "card" )
                 {
-                    qWarning() << "Expected a \"card\" tag. Found a" << xml.name() << "tag.";
+                    qCWarning(KPAT_LOG) << "Expected a \"card\" tag. Found a" << xml.name() << "tag.";
                     return false;
                 }
 
                 KCard * card = cardHash.value( readIntAttribute( xml, QStringLiteral("id") ) );
                 if ( !card )
                 {
-                    qWarning() << "Unrecognized card.";
+                    qCWarning(KPAT_LOG) << "Unrecognized card.";
                     return false;
                 }
 
@@ -845,7 +831,7 @@ void DealerScene::startNew( int dealNumber )
         p->clear();
 
     m_dealInProgress = true;
-    restart( shuffled( deck()->cards(), m_dealNumber ) );
+    restart( KpatShuffle::shuffled<KCard*>( deck()->cards(), m_dealNumber ) );
     m_dealInProgress = false;
 
     takeState();
@@ -1642,14 +1628,14 @@ void DealerScene::demo()
 
         if ( destPile->isEmpty() )
         {
-            qDebug() << "Moving" << card->objectName()
+            qCDebug(KPAT_LOG) << "Moving" << card->objectName()
                      << "from the" << sourcePile->objectName()
                      << "pile to the" << destPile->objectName()
                      << "pile, which is empty";
         }
         else
         {
-            qDebug() << "Moving" << card->objectName()
+            qCDebug(KPAT_LOG) << "Moving" << card->objectName()
                      << "from the" << sourcePile->objectName()
                      << "pile to the" << destPile->objectName()
                      << "pile, putting it on top of"
