@@ -39,6 +39,7 @@
 #include "dealerinfo.h"
 #include "speeds.h"
 #include "patsolve/golfsolver.h"
+#include "pileutils.h"
 
 #include <KLocalizedString>
 
@@ -169,6 +170,20 @@ void Golf::setGameState( const QString & state )
     emit newCardsPossible( !talon->isEmpty() );
 }
 
+QString Golf::solverFormat() const
+{
+    QString output;
+    output += QStringLiteral("Foundations: ") + (waste->isEmpty() ? QStringLiteral("-") : cardToRankSuitString(waste->topCard())) + '\n';
+    output += "Talon:";
+    for ( int i = talon->count()-1; i >= 0; --i )
+    {
+        output += QStringLiteral(" ")+cardToRankSuitString(talon->at( i ));
+    }
+    output += "\n";
+    for (int i = 0; i < 7 ; i++)
+        cardsListToLine(output, stack[i]->cards());
+    return output;
+}
 
 static class GolfDealerInfo : public DealerInfo
 {
