@@ -151,13 +151,13 @@ bool checkAddAlternateColorDescendingFromKing( const QList<KCard*> & oldCards, c
 QString suitToString(int s) {
     switch (s) {
         case KCardDeck::Clubs:
-            return "C";
+            return QStringLiteral("C");
         case KCardDeck::Hearts:
-            return "H";
+            return QStringLiteral("H");
         case KCardDeck::Diamonds:
-            return "D";
+            return QStringLiteral("D");
         case KCardDeck::Spades:
-            return "S";
+            return QStringLiteral("S");
         default:
             exit(-1);
     }
@@ -168,17 +168,36 @@ QString rankToString(int r)
 {
     switch (r) {
         case KCardDeck::King:
-            return "K";
+            return QStringLiteral("K");
         case KCardDeck::Ace:
-            return "A";
+            return QStringLiteral("A");
         case KCardDeck::Jack:
-            return "J";
+            return QStringLiteral("J");
         case KCardDeck::Queen:
-            return "Q";
+            return QStringLiteral("Q");
         case KCardDeck::Ten:
-            return "T";
+            return QStringLiteral("T");
         default:
             return QString::number(r);
     }
 }
 
+QString cardToRankSuitString(const KCard *const card)
+{
+    return rankToString(card->rank()) + suitToString(card->suit());
+}
+
+void cardsListToLine(QString & output, const QList<KCard*> cards)
+{
+    bool first = true;
+    for (QList<KCard*>::ConstIterator it = cards.constBegin(); it != cards.constEnd(); ++it)
+    {
+        if (!first)
+        {
+            output += ' ';
+        }
+        first = false;
+        output += cardToRankSuitString(*it);
+    }
+    output += '\n';
+}
